@@ -14,7 +14,6 @@ from tiddlywebplugins.tiddlyspace.serversettings import ServerSettings
 from tiddlywebplugins.tiddlyspace.handler import (home, friendly_uri,
         get_identities, get_space_tiddlers)
 from tiddlywebplugins.tiddlyspace.profiles import add_profile_routes
-from tiddlywebplugins.tiddlyspace.repudiator import RepudiatorController
 from tiddlywebplugins.tiddlyspace.safemode import safe_mode
 from tiddlywebplugins.tiddlyspace.spaces import add_spaces_routes
 
@@ -52,8 +51,3 @@ def establish_www(config):
         config['server_response_filters'].insert(
                 config['server_response_filters'].
                 index(PrettyHTTPExceptor) + 1, AllowOrigin)
-
-    if RepudiatorController not in config['server_response_filters']:
-        config['server_response_filters'].insert(
-                config['server_response_filters'].
-                index(PrettyHTTPExceptor) + 1, RepudiatorController)
